==> ds-bootstrap-0.0.21.tgz: package/esm/Widgets/TextField/TextField.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from "react";
import { unstable_trace as trace } from "scheduler/tracing";
import { TransTitle, updateValue } from "@ui-schema/ui-schema";
import { ValidityHelperText } from "../../Component/LocaleHelperText/LocaleHelperText";
import { useUID } from "react-uid";

const StringRenderer = ({
  ownKey,
  schema,
  value,
  multiline = false,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors,
  type,
  rows
}) => {
  const format = schema.get('format');
  const uid = useUID();
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormGroup = ["form-group"];
  let classFormControl = ["form-control"];

  if (showValidity && errors.size) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.size) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement("div", {
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: 'uis-' + uid
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  })), /*#__PURE__*/React.createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: e => trace("textfield onchange", performance.now(), () => {
      const value = e.target.value;
      const target = e.target;

      if (type === 'number') {
        if (isNaN(value * 1)) {
          console.error('Invalid Type: input not a number in:', target);
          return;
        }

        onChange(updateValue(storeKeys, value === '' ? '' : value * 1, required, type || schema.get('type')));
      } else {
        onChange(updateValue(storeKeys, value, required, type || schema.get('type')));
      }
    })
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

const TextRenderer = (_ref) => {
  let {
    schema
  } = _ref,
      props = _objectWithoutProperties(_ref, ["schema"]);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

const NumberRenderer = (_ref2) => {
  let {
    schema
  } = _ref2,
      props = _objectWithoutProperties(_ref2, ["schema"]);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

export { StringRenderer, NumberRenderer, TextRenderer };

==> ds-bootstrap-0.1.0.tgz: package/esm/Widgets/TextField/TextField.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from "react";
import { TransTitle, updateValue } from "@ui-schema/ui-schema";
import { ValidityHelperText } from "../../Component/LocaleHelperText/LocaleHelperText";
import { useUID } from "react-uid";

const StringRenderer = ({
  ownKey,
  schema,
  value,
  multiline = false,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors,
  type,
  rows
}) => {
  const format = schema.get('format');
  const uid = useUID();
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormGroup = ["form-group"];
  let classFormControl = ["form-control"];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/React.createElement("div", {
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/React.createElement("label", {
    htmlFor: 'uis-' + uid
  }, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  })), /*#__PURE__*/React.createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: e => {
      const value = e.target.value;
      const target = e.target;

      if (type === 'number') {
        if (isNaN(value * 1)) {
          console.error('Invalid Type: input not a number in:', target);
          return;
        }

        onChange(updateValue(storeKeys, value === '' ? '' : value * 1, required, type || schema.get('type')));
      } else {
        onChange(updateValue(storeKeys, value, required, type || schema.get('type')));
      }
    }
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

const TextRenderer = (_ref) => {
  let {
    schema
  } = _ref,
      props = _objectWithoutProperties(_ref, ["schema"]);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

const NumberRenderer = (_ref2) => {
  let {
    schema
  } = _ref2,
      props = _objectWithoutProperties(_ref2, ["schema"]);

  return /*#__PURE__*/React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

export { StringRenderer, NumberRenderer, TextRenderer };
